package net.sourceforge.chopchophttpclient;

import java.net.URI;

public interface ProgressListener {
	/**
	 * Method is called each time a block of bytes is read from content being downloaded.  Your implementation may
	 * use this to update a progress bar for instance.
	 * 
	 * <p style="font-weight: bold;">Note:</p> Do not rely on this method as a way of determining that a download
	 * 		is complete.  Rely on the download method call instead.
	 * 
	 * <p style="font-weight: bold;">Note:</p> Multiple threads may call this method at the same time.  Your
	 * 		implementation must be thread safe.
	 * 
	 * @param uri The URI that has progress to report.  Immutable.
	 * @param totalBytesRead The total number of bytes read thus far (not just the last number of bytes read)
	 * @param contentLength The length of the content.  Negative if not known.
	 */
	public void update(final URI uri, final long totalBytesRead, final long contentLength);
}
